#import "TZDBHelper.dll"

/*
  TZDB wrapper provides Delphi's TBundledTimeZone functionality via common DLL.

  Function description: see http://code.google.com/p/delphi-tzdb/

  Note the TZDB uses TDateTime type which is Double where integer part is number
  of days since 1970 and fraction part represents day time. MT4 uses datetime
  represented as integer in Unix convention, i.e. number of seconds since 1970.

  For conversion use TZDateTimeToUnix/TZUnixToDateTime functions.
  TZDB supports daylight saving time adjustments.

  Examples:

    datetime udt1 = TimeCurrent();
    double dt1 = TZUnixToDateTime(udt1);
    string tz1 = "GMT-2";   // GoMarkets uses some strange time at my PC, it's one hour ahead CET
    string tz2 = "America/New_York";
    datetime utc = TZDateTimeToUnix(TZToUniversalTime(tz1, dt1, false));
    double dt2 = TZToLocalTime(tz2, TZUnixToDateTime(utc));
    datetime udt2 = TZDateTimeToUnix(dt2);
*/

#define SERVER_TZ "GMT-2"

#define LTT_STANDARD 0
#define LTT_DAYLIGHT 1
#define LTT_AMBIGUOUS 2
#define LTT_INVALID 3

string   TZGetLastError();
bool     TZIsValid(string);
string   TZGetAbbreviation(string, double, bool);
string   TZGetDisplayName(string, double, bool);
int      TZGetLocalTimeType(string, double);
bool     TZIsAmbiguousTime(string, double);
bool     TZIsDaylightTime(string, double, bool);
bool     TZIsInvalidTime(string, double);
bool     TZIsStandardTime(string, double, bool);
datetime TZGetUtcOffset(string, double, bool);
double   TZToLocalTime(string, double);
double   TZToUniversalTime(string, double, bool);
datetime TZDateTimeToUnix(double);
double   TZUnixToDateTime(datetime);

//#import "TZDBHelper.ex4"

double TZSinceMidnightTime(double);
double TZMidnightTime(double);

// cannot put in TZDBHelper.mq4 because of dependency on TZ* functions 
//double TZLocalToLocalTime(string fromTZ, string toTZ, double dt, bool forceDST) {
//  if ((fromTZ == toTZ) || (fromTZ == "") || (toTZ == "")) return (dt);
//  dt = TZToUniversalTime(fromTZ, dt, forceDST); 
//  dt = TZToLocalTime(toTZ, dt);
//  return (dt);
//}